# 🚻👀 `vwc`

Like `wc`, but with a live preview output to stderr if it's a tty.

## ▶️ installing

```bash
$ pip install vwc
$ echo "hey" | wc -l
1
```

## ✅ To Do

[x] Release something
[ ] Integration tests
[ ] Detect platform and mirror it
[ ] Compile with Cython if available

## ⚖️ License

WTFP with one additional clause:

* ⛔ Don't blame me

## Links

* [🏠 home](https://bitplane.net/dev/python/vwc)
* [🐱 github](https://github.com/bitplane/vwc)
* [🐍 pypi](https://pypi.org/project/vwc)
* [📖 pydoc](https://bitplane.net/dev/python/vwc/pydoc)
